/*
 * QQQ - Low-code Application Framework for Engineers.
 * Copyright (C) 2021-2024.  Kingsrook, LLC
 * 651 N Broad St Ste 205 # 6917 | Middletown DE 19709 | United States
 * contact@kingsrook.com
 * https://github.com/Kingsrook/
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

import Box from "@mui/material/Box";
import BlockElementWrapper from "qqq/components/widgets/blocks/BlockElementWrapper";
import {StandardBlockComponentProps} from "qqq/components/widgets/blocks/BlockModels";
import DumpJsonBox from "qqq/utils/DumpJsonBox";

/*******************************************************************************
 ** Block that renders ... just some text.
 **
 ** ${text}
 *******************************************************************************/
export default function TextBlock({widgetMetaData, data}: StandardBlockComponentProps): JSX.Element
{
   let color = "rgba(0, 0, 0, 0.87)";
   if (data.styles?.standardColor)
   {
      switch (data.styles?.standardColor)
      {
         case "SUCCESS":
            color = "#2BA83F";
            break;
         case "WARNING":
            color = "#FBA132";
            break;
         case "ERROR":
            color = "#FB4141";
            break;
         case "INFO":
            color = "#458CFF";
            break;
         case "MUTED":
            color = "#7b809a";
            break;
      }
   }

   let boxStyle = {};
   if (data.styles?.isAlert)
   {
      boxStyle =
         {
            border: `1px solid ${color}`,
            background: `${color}40`,
            padding: "0.5rem",
            borderRadius: "0.5rem",
         };
   }

   const text = data.values.interpolatedText ?? data.values.text;
   const lines = text.split("\n");

   return (
      <BlockElementWrapper metaData={widgetMetaData} data={data} slot="">
         <Box display="inline-block" lineHeight="1.2" sx={boxStyle}>
            <span style={{fontSize: "1rem", color: color}}>
               {lines.map((line: string, index: number) =>
                  (
                     <div key={index}>{line}</div>
                  ))
               }</span>
         </Box>
      </BlockElementWrapper>
   );
}
